==> antlr-java-parser-1.0.1-sources.jar: com/github/antlrjavaparser/adapter/PackageDeclarationContextAdapter.java <==
/*
 * This file is part of antlr-java-parser.
 *
 *     antlr-java-parser is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     antlr-java-parser is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with antlr-java-parser.  If not, see <http://www.gnu.org/licenses/>.
 */

package com.github.antlrjavaparser.adapter;

import com.github.antlrjavaparser.Java7Parser;
import com.github.antlrjavaparser.api.PackageDeclaration;

public class PackageDeclarationContextAdapter implements Adapter<PackageDeclaration, Java7Parser.PackageDeclarationContext> {
    public PackageDeclaration adapt(Java7Parser.PackageDeclarationContext context) {
        if (context == null) {
            return null;
        }

        PackageDeclaration packageDeclaration = new PackageDeclaration();
        packageDeclaration.setName(Adapters.getQualifiedNameContextAdapter().adapt(context.qualifiedName()));

        if (context.annotations() != null) {
            packageDeclaration.setAnnotations(Adapters.getAnnotationsContextAdapter().adapt(context.annotations()));
        }

        return packageDeclaration;
    }
}

==> antlr-java-parser-1.0.11-sources.jar: com/github/antlrjavaparser/adapter/PackageDeclarationContextAdapter.java <==
/*
 * This file is part of antlr-java-parser.
 *
 *     antlr-java-parser is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     antlr-java-parser is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with antlr-java-parser.  If not, see <http://www.gnu.org/licenses/>.
 */

package com.github.antlrjavaparser.adapter;

import com.github.antlrjavaparser.Java7Parser;
import com.github.antlrjavaparser.api.PackageDeclaration;

public class PackageDeclarationContextAdapter implements Adapter<PackageDeclaration, Java7Parser.PackageDeclarationContext> {
    public PackageDeclaration adapt(Java7Parser.PackageDeclarationContext context, AdapterParameters adapterParameters) {
        if (context == null) {
            return null;
        }

        PackageDeclaration packageDeclaration = new PackageDeclaration();
        AdapterUtil.setComments(packageDeclaration, context, adapterParameters);
        packageDeclaration.setName(Adapters.getQualifiedNameContextAdapter().adapt(context.qualifiedName(), adapterParameters));

        if (context.annotations() != null) {
            packageDeclaration.setAnnotations(Adapters.getAnnotationsContextAdapter().adapt(context.annotations(), adapterParameters));
        }

        return packageDeclaration;
    }
}
